/*
 * Copyright 2008-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.synyx.hades.domain;

/**
 * Abstract interface for pagination information.
 * 
 * @author Oliver Gierke
 */
public interface Pageable {

    /**
     * Returns the page to be returned.
     * 
     * @return the page to be returned.
     */
    int getPageNumber();


    /**
     * Returns the number of items to be returned.
     * 
     * @return the number of items of that page
     */
    int getPageSize();


    /**
     * Returns the first item relatively to the total number of items.
     * 
     * @return the first item to be returned
     */
    int getFirstItem();


    /**
     * Returns the sorting parameters.
     * 
     * @return
     */
    Sort getSort();
}
